# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['serapeum_utils']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'serapeum-utils',
    'version': '0.1.1',
    'description': 'utility package',
    'long_description': '![GitHub release (latest by date)](https://img.shields.io/github/v/release/Serapieum-of-alex/serapeum_utils)\n[![Python Versions](https://img.shields.io/pypi/pyversions/HAPI-Nile.png)](https://img.shields.io/pypi/pyversions/HAPI-Nile)\n[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)\n[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)\n[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Serapieum-of-alex/Hapi.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Serapieum-of-alex/Hapi/context:python)\n\nCurrent build status\n====================\n\n\n<table><tr><td>All platforms:</td>\n    <td>\n      <a href="https://dev.azure.com/conda-forge/feedstock-builds/_build/latest?definitionId=12419&branchName=master">\n        <img src="https://dev.azure.com/conda-forge/feedstock-builds/_apis/build/status/hapi-feedstock?branchName=master">\n      </a>\n    </td>\n  </tr>\n</table>\n\n![GitHub last commit](https://img.shields.io/github/last-commit/Serapieum-of-alex/serapeum_utils)\n![GitHub forks](https://img.shields.io/github/forks/Serapieum-of-alex/serapeum_utils?style=social)\n![GitHub Repo stars](https://img.shields.io/github/stars/Serapieum-of-alex/serapeum_utils?style=social)\n\n\n\n[![Github all releases](https://img.shields.io/github/downloads/Naereen/StrapDown.js/total.svg)](https://GitHub.com/Naereen/StrapDown.js/releases/)\n\n\nCurrent release info\n====================\n\n| Name | Downloads                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | Version | Platforms |\n| --- |------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------| --- | --- |\n| [![Conda Recipe](https://img.shields.io/badge/recipe-serapeum_utils-green.svg)](https://anaconda.org/conda-forge/serapeum_utils) | [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/serapeum_utils.svg)](https://anaconda.org/conda-forge/serapeum_utils) [![Downloads](https://pepy.tech/badge/serapeum_utils-nile)](https://pepy.tech/project/serapeum_utils-nile) [![Downloads](https://pepy.tech/badge/serapeum_utils-nile/month)](https://pepy.tech/project/serapeum_utils-nile)  [![Downloads](https://pepy.tech/badge/serapeum_utils-nile/week)](https://pepy.tech/project/serapeum_utils-nile)  ![PyPI - Downloads](https://img.shields.io/pypi/dd/serapeum_utils-nile?color=blue&style=flat-square) ![GitHub all releases](https://img.shields.io/github/downloads/Serapieum-of-alex/serapeum_utils/total) ![GitHub release (latest by date)](https://img.shields.io/github/downloads/Serapieum-of-alex/serapeum_utils/1.2.3/total) | [![Conda Version](https://img.shields.io/conda/vn/conda-forge/serapeum_utils.svg)](https://anaconda.org/conda-forge/serapeum_utils) [![PyPI version](https://badge.fury.io/py/serapeum_utils-Nile.svg)](https://badge.fury.io/py/serapeum_utils-Nile) [![Anaconda-Server Badge](https://anaconda.org/conda-forge/serapeum_utils/badges/version.svg)](https://anaconda.org/conda-forge/serapeum_utils) | [![Conda Platforms](https://img.shields.io/conda/pn/conda-forge/serapeum_utils.svg)](https://anaconda.org/conda-forge/serapeum_utils) [![Join the chat at https://gitter.im/serapeum_utils-Nile/serapeum_utils](https://badges.gitter.im/serapeum_utils-Nile/serapeum_utils.svg)](https://gitter.im/serapeum_utils-Nile/serapeum_utils?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge) |\n\n\n\n\n\nserapeum_utils - utility library for Python\n=====================================================================\n**serapeum_utils** is an open-source Python utility package\n\n\nserapeum_utils\n\nMain Features\n-------------\n  -\n\n\nInstalling serapeum_utils\n===============\n\nInstalling `serapeum_utils` from the `conda-forge` channel can be achieved by:\n\n```\nconda install -c conda-forge serapeum_utils\n```\n\nIt is possible to list all of the versions of `serapeum_utils` available on your platform with:\n\n```\nconda search serapeum_utils --channel conda-forge\n```\n\n## Install from Github\nto install the last development to time you can install the library from github\n```\npip install git+https://github.com/Serapieum-of-alex/serapeum_utils\n```\n\n## pip\nto install the last release you can easly use pip\n```\npip install serapeum_utils==0.1.1\n```\n\nQuick start\n===========\n\n```\n  >>> import serapeum_utils\n```\n',
    'author': 'Mostafa Farrag',
    'author_email': 'moah.farag@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/Serapieum-of-alex/serapeum_utils',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
